@@ -37,7 +37,10 @@ pub mod outgoing {
 
     use super::Opcode;
     use serde::{Deserialize, Serialize};
-    use twilight_model::{gateway::payload::incoming::VoiceServerUpdate, id::GuildId};
+    use twilight_model::{
+        gateway::payload::incoming::VoiceServerUpdate,
+        id::{marker::GuildMarker, Id},
+    };
 
     /// An outgoing event to send to Lavalink.
     #[derive(Clone, Debug, Deserialize, PartialEq, Serialize)]
@@ -116,14 +119,14 @@ pub mod outgoing {
     #[serde(rename_all = "camelCase")]
     pub struct Destroy {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
     }
 
     impl Destroy {
         /// Create a new destroy event.
-        pub const fn new(guild_id: GuildId) -> Self {
+        pub const fn new(guild_id: Id<GuildMarker>) -> Self {
             Self {
                 guild_id,
                 op: Opcode::Destroy,
@@ -131,8 +134,8 @@ pub mod outgoing {
         }
     }
 
-    impl From<GuildId> for Destroy {
-        fn from(guild_id: GuildId) -> Self {
+    impl From<Id<GuildMarker>> for Destroy {
+        fn from(guild_id: Id<GuildMarker>) -> Self {
             Self {
                 guild_id,
                 op: Opcode::Destroy,
@@ -148,20 +151,20 @@ pub mod outgoing {
         /// The bands to use as part of the equalizer.
         pub bands: Vec<EqualizerBand>,
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
     }
 
     impl Equalizer {
         /// Create a new equalizer event.
-        pub fn new(guild_id: GuildId, bands: Vec<EqualizerBand>) -> Self {
+        pub fn new(guild_id: Id<GuildMarker>, bands: Vec<EqualizerBand>) -> Self {
             Self::from((guild_id, bands))
         }
     }
 
-    impl From<(GuildId, Vec<EqualizerBand>)> for Equalizer {
-        fn from((guild_id, bands): (GuildId, Vec<EqualizerBand>)) -> Self {
+    impl From<(Id<GuildMarker>, Vec<EqualizerBand>)> for Equalizer {
+        fn from((guild_id, bands): (Id<GuildMarker>, Vec<EqualizerBand>)) -> Self {
             Self {
                 bands,
                 guild_id,
@@ -200,7 +203,7 @@ pub mod outgoing {
     #[serde(rename_all = "camelCase")]
     pub struct Pause {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
         /// Whether to pause the player.
@@ -213,13 +216,13 @@ pub mod outgoing {
         /// Create a new pause event.
         ///
         /// Set to `true` to pause the player or `false` to resume it.
-        pub fn new(guild_id: GuildId, pause: bool) -> Self {
+        pub fn new(guild_id: Id<GuildMarker>, pause: bool) -> Self {
             Self::from((guild_id, pause))
         }
     }
 
-    impl From<(GuildId, bool)> for Pause {
-        fn from((guild_id, pause): (GuildId, bool)) -> Self {
+    impl From<(Id<GuildMarker>, bool)> for Pause {
+        fn from((guild_id, pause): (Id<GuildMarker>, bool)) -> Self {
             Self {
                 guild_id,
                 op: Opcode::Pause,
@@ -241,7 +244,7 @@ pub mod outgoing {
         #[serde(skip_serializing_if = "Option::is_none")]
         pub end_time: Option<u64>,
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// Whether or not to replace the currently playing track with this new
         /// track.
         ///
@@ -262,7 +265,7 @@ pub mod outgoing {
     impl Play {
         /// Create a new play event.
         pub fn new(
-            guild_id: GuildId,
+            guild_id: Id<GuildMarker>,
             track: impl Into<String>,
             start_time: impl Into<Option<u64>>,
             end_time: impl Into<Option<u64>>,
@@ -272,31 +275,31 @@ pub mod outgoing {
         }
     }
 
-    impl<T: Into<String>> From<(GuildId, T)> for Play {
-        fn from((guild_id, track): (GuildId, T)) -> Self {
+    impl<T: Into<String>> From<(Id<GuildMarker>, T)> for Play {
+        fn from((guild_id, track): (Id<GuildMarker>, T)) -> Self {
             Self::from((guild_id, track, None, None, true))
         }
     }
 
-    impl<T: Into<String>, S: Into<Option<u64>>> From<(GuildId, T, S)> for Play {
-        fn from((guild_id, track, start_time): (GuildId, T, S)) -> Self {
+    impl<T: Into<String>, S: Into<Option<u64>>> From<(Id<GuildMarker>, T, S)> for Play {
+        fn from((guild_id, track, start_time): (Id<GuildMarker>, T, S)) -> Self {
             Self::from((guild_id, track, start_time, None, true))
         }
     }
 
-    impl<T: Into<String>, S: Into<Option<u64>>, E: Into<Option<u64>>> From<(GuildId, T, S, E)>
-        for Play
+    impl<T: Into<String>, S: Into<Option<u64>>, E: Into<Option<u64>>>
+        From<(Id<GuildMarker>, T, S, E)> for Play
     {
-        fn from((guild_id, track, start_time, end_time): (GuildId, T, S, E)) -> Self {
+        fn from((guild_id, track, start_time, end_time): (Id<GuildMarker>, T, S, E)) -> Self {
             Self::from((guild_id, track, start_time, end_time, true))
         }
     }
 
-    impl<T: Into<String>, S: Into<Option<u64>>, E: Into<Option<u64>>> From<(GuildId, T, S, E, bool)>
-        for Play
+    impl<T: Into<String>, S: Into<Option<u64>>, E: Into<Option<u64>>>
+        From<(Id<GuildMarker>, T, S, E, bool)> for Play
     {
         fn from(
-            (guild_id, track, start_time, end_time, no_replace): (GuildId, T, S, E, bool),
+            (guild_id, track, start_time, end_time, no_replace): (Id<GuildMarker>, T, S, E, bool),
         ) -> Self {
             Self {
                 end_time: end_time.into(),
@@ -315,7 +318,7 @@ pub mod outgoing {
     #[serde(rename_all = "camelCase")]
     pub struct Seek {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
         /// The position in milliseconds to seek to.
@@ -324,13 +327,13 @@ pub mod outgoing {
 
     impl Seek {
         /// Create a new seek event.
-        pub fn new(guild_id: GuildId, position: i64) -> Self {
+        pub fn new(guild_id: Id<GuildMarker>, position: i64) -> Self {
             Self::from((guild_id, position))
         }
     }
 
-    impl From<(GuildId, i64)> for Seek {
-        fn from((guild_id, position): (GuildId, i64)) -> Self {
+    impl From<(Id<GuildMarker>, i64)> for Seek {
+        fn from((guild_id, position): (Id<GuildMarker>, i64)) -> Self {
             Self {
                 guild_id,
                 op: Opcode::Seek,
@@ -347,18 +350,18 @@ pub mod outgoing {
         /// The opcode of the event.
         pub op: Opcode,
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
     }
 
     impl Stop {
         /// Create a new stop event.
-        pub fn new(guild_id: GuildId) -> Self {
+        pub fn new(guild_id: Id<GuildMarker>) -> Self {
             Self::from(guild_id)
         }
     }
 
-    impl From<GuildId> for Stop {
-        fn from(guild_id: GuildId) -> Self {
+    impl From<Id<GuildMarker>> for Stop {
+        fn from(guild_id: Id<GuildMarker>) -> Self {
             Self {
                 guild_id,
                 op: Opcode::Stop,
@@ -374,7 +377,7 @@ pub mod outgoing {
         /// The inner event being forwarded to a node.
         pub event: SlimVoiceServerUpdate,
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
         /// The session ID of the voice channel.
@@ -384,7 +387,7 @@ pub mod outgoing {
     impl VoiceUpdate {
         /// Create a new voice update event.
         pub fn new(
-            guild_id: GuildId,
+            guild_id: Id<GuildMarker>,
             session_id: impl Into<String>,
             event: SlimVoiceServerUpdate,
         ) -> Self {
@@ -392,8 +395,10 @@ pub mod outgoing {
         }
     }
 
-    impl<T: Into<String>> From<(GuildId, T, SlimVoiceServerUpdate)> for VoiceUpdate {
-        fn from((guild_id, session_id, event): (GuildId, T, SlimVoiceServerUpdate)) -> Self {
+    impl<T: Into<String>> From<(Id<GuildMarker>, T, SlimVoiceServerUpdate)> for VoiceUpdate {
+        fn from(
+            (guild_id, session_id, event): (Id<GuildMarker>, T, SlimVoiceServerUpdate),
+        ) -> Self {
             Self {
                 event,
                 guild_id,
@@ -411,7 +416,7 @@ pub mod outgoing {
         /// The endpoint of the Discord voice server.
         pub endpoint: Option<String>,
         /// The guild ID of the player.
-        pub guild_id: Option<GuildId>,
+        pub guild_id: Option<Id<GuildMarker>>,
         /// The authentication token used by the bot to connect to the Discord
         /// voice server.
         pub token: String,
@@ -433,7 +438,7 @@ pub mod outgoing {
     #[serde(rename_all = "camelCase")]
     pub struct Volume {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
         /// The volume of the player from 0 to 1000. 100 is the default.
@@ -442,13 +447,13 @@ pub mod outgoing {
 
     impl Volume {
         /// Create a new volume event.
-        pub fn new(guild_id: GuildId, volume: i64) -> Self {
+        pub fn new(guild_id: Id<GuildMarker>, volume: i64) -> Self {
             Self::from((guild_id, volume))
         }
     }
 
-    impl From<(GuildId, i64)> for Volume {
-        fn from((guild_id, volume): (GuildId, i64)) -> Self {
+    impl From<(Id<GuildMarker>, i64)> for Volume {
+        fn from((guild_id, volume): (Id<GuildMarker>, i64)) -> Self {
             Self {
                 guild_id,
                 op: Opcode::Volume,
@@ -463,7 +468,7 @@ pub mod incoming {
 
     use super::Opcode;
     use serde::{Deserialize, Serialize};
-    use twilight_model::id::GuildId;
+    use twilight_model::id::{marker::GuildMarker, Id};
 
     /// An incoming event from a Lavalink node.
     #[derive(Clone, Debug, Deserialize, PartialEq, Serialize)]
@@ -500,7 +505,7 @@ pub mod incoming {
     #[serde(rename_all = "camelCase")]
     pub struct PlayerUpdate {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The opcode of the event.
         pub op: Opcode,
         /// The new state of the player.
@@ -512,10 +517,12 @@ pub mod incoming {
     #[non_exhaustive]
     #[serde(rename_all = "camelCase")]
     pub struct PlayerUpdateState {
-        /// The new position of the player.
-        pub position: i64,
-        /// The new time of the player.
+        /// True when the player is connected to the voice gateway.
+        pub connected: bool,
+        /// Unix timestamp of the player in milliseconds.
         pub time: i64,
+        /// Track position in milliseconds. None if not playing anything.
+        pub position: Option<i64>,
     }
 
     /// Statistics about a node and its host.
@@ -603,7 +610,7 @@ pub mod incoming {
     #[serde(rename_all = "camelCase")]
     pub struct TrackEnd {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The type of track event.
         #[serde(rename = "type")]
         pub kind: TrackEventType,
@@ -623,7 +630,7 @@ pub mod incoming {
     #[serde(rename_all = "camelCase")]
     pub struct TrackStart {
         /// The guild ID of the player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// The type of track event.
         #[serde(rename = "type")]
         pub kind: TrackEventType,
@@ -639,7 +646,7 @@ pub mod incoming {
     #[serde(rename_all = "camelCase")]
     pub struct WebsocketClosed {
         /// Guild ID of the associated player.
-        pub guild_id: GuildId,
+        pub guild_id: Id<GuildMarker>,
         /// Type of track event.
         #[serde(rename = "type")]
         pub kind: TrackEventType,
@@ -682,7 +689,7 @@ mod tests {
     use serde_test::Token;
     use static_assertions::{assert_fields, assert_impl_all};
     use std::fmt::Debug;
-    use twilight_model::id::GuildId;
+    use twilight_model::id::{marker::GuildMarker, Id};
 
     assert_fields!(Destroy: guild_id, op);
     assert_impl_all!(
@@ -690,7 +697,7 @@ mod tests {
         Debug,
         Deserialize<'static>,
         Eq,
-        From<GuildId>,
+        From<Id<GuildMarker>>,
         PartialEq,
         Send,
         Serialize,
@@ -712,7 +719,7 @@ mod tests {
         Equalizer: Clone,
         Debug,
         Deserialize<'static>,
-        From<(GuildId, Vec<EqualizerBand>)>,
+        From<(Id<GuildMarker>, Vec<EqualizerBand>)>,
         PartialEq,
         Send,
         Serialize,
@@ -752,7 +759,7 @@ mod tests {
         Debug,
         Deserialize<'static>,
         Eq,
-        From<(GuildId, bool)>,
+        From<(Id<GuildMarker>, bool)>,
         PartialEq,
         Send,
         Serialize,
@@ -786,17 +793,17 @@ mod tests {
         Debug,
         Deserialize<'static>,
         Eq,
-        From<(GuildId, String)>,
-        From<(GuildId, String, Option<u64>)>,
-        From<(GuildId, String, u64)>,
-        From<(GuildId, String, Option<u64>, Option<u64>)>,
-        From<(GuildId, String, Option<u64>, u64)>,
-        From<(GuildId, String, u64, Option<u64>)>,
-        From<(GuildId, String, u64, u64)>,
-        From<(GuildId, String, Option<u64>, Option<u64>, bool)>,
-        From<(GuildId, String, Option<u64>, u64, bool)>,
-        From<(GuildId, String, u64, Option<u64>, bool)>,
-        From<(GuildId, String, u64, u64, bool)>,
+        From<(Id<GuildMarker>, String)>,
+        From<(Id<GuildMarker>, String, Option<u64>)>,
+        From<(Id<GuildMarker>, String, u64)>,
+        From<(Id<GuildMarker>, String, Option<u64>, Option<u64>)>,
+        From<(Id<GuildMarker>, String, Option<u64>, u64)>,
+        From<(Id<GuildMarker>, String, u64, Option<u64>)>,
+        From<(Id<GuildMarker>, String, u64, u64)>,
+        From<(Id<GuildMarker>, String, Option<u64>, Option<u64>, bool)>,
+        From<(Id<GuildMarker>, String, Option<u64>, u64, bool)>,
+        From<(Id<GuildMarker>, String, u64, Option<u64>, bool)>,
+        From<(Id<GuildMarker>, String, u64, u64, bool)>,
         PartialEq,
         Send,
         Serialize,
@@ -808,7 +815,7 @@ mod tests {
         Debug,
         Deserialize<'static>,
         Eq,
-        From<(GuildId, i64)>,
+        From<(Id<GuildMarker>, i64)>,
         PartialEq,
         Send,
         Serialize,
@@ -879,7 +886,7 @@ mod tests {
         Debug,
         Deserialize<'static>,
         Eq,
-        From<GuildId>,
+        From<Id<GuildMarker>>,
         PartialEq,
         Send,
         Serialize,
@@ -931,7 +938,7 @@ mod tests {
         Debug,
         Deserialize<'static>,
         Eq,
-        From<(GuildId, String, SlimVoiceServerUpdate)>,
+        From<(Id<GuildMarker>, String, SlimVoiceServerUpdate)>,
         PartialEq,
         Send,
         Serialize,
