@@ -44,7 +44,7 @@ use tokio_tungstenite::{
     tungstenite::{Error as TungsteniteError, Message},
     MaybeTlsStream, WebSocketStream,
 };
-use twilight_model::id::UserId;
+use twilight_model::id::{marker::UserMarker, Id};
 
 /// An error occurred while either initializing a connection or while running
 /// its event loop.
@@ -237,7 +237,7 @@ pub struct NodeConfig {
     /// The number of shards in use by the bot.
     pub shard_count: u64,
     /// The user ID of the bot.
-    pub user_id: UserId,
+    pub user_id: Id<UserMarker>,
 }
 
 /// Configuration for a session which can be resumed.
@@ -274,7 +274,7 @@ impl NodeConfig {
     ///
     /// [`Lavalink`]: crate::client::Lavalink
     pub fn new(
-        user_id: UserId,
+        user_id: Id<UserMarker>,
         shard_count: u64,
         address: impl Into<SocketAddr>,
         authorization: impl Into<String>,
@@ -290,7 +290,7 @@ impl NodeConfig {
     }
 
     const fn _new(
-        user_id: UserId,
+        user_id: Id<UserMarker>,
         shard_count: u64,
         address: SocketAddr,
         authorization: String,
@@ -595,7 +595,7 @@ impl Connection {
             }
         };
 
-        player.set_position(update.state.position);
+        player.set_position(update.state.position.unwrap_or(0));
         player.set_time(update.state.time);
 
         Ok(())
